Forge runtime engine.
Implements the Axum gateway, job worker, workflow executor, cron scheduler, daemon runner, reactivity system, cluster coordination, rate limiting, observability, and product analytics (signals).
The runtime wires together types from forge-core into a production server
started via Forge::builder().auto_register().build()?.run().await.
Re-exports
pub use cluster::GracefulShutdown;pub use cluster::HeartbeatConfig;pub use cluster::HeartbeatLoop;pub use cluster::InFlightGuard;pub use cluster::LeaderConfig;pub use cluster::LeaderElection;pub use cluster::LeaderGuard;pub use cluster::NodeCounts;pub use cluster::NodeRegistry;pub use cluster::ShutdownConfig;pub use cron::CronEntry;pub use cron::CronRecord;pub use cron::CronRegistry;pub use cron::CronRunner;pub use cron::CronStatus;pub use daemon::DaemonEntry;pub use daemon::DaemonRegistry;pub use daemon::DaemonRunner;pub use daemon::DaemonRunnerConfig;pub use db::Database;pub use function::FunctionExecutor;pub use function::FunctionRegistry;pub use function::FunctionRouter;pub use function::RouteResult;pub use gateway::AuthMiddleware;pub use gateway::GatewayConfig;pub use gateway::GatewayServer;pub use gateway::RpcError;pub use gateway::RpcHandler;pub use gateway::RpcRequest;pub use gateway::RpcResponse;pub use gateway::TracingMiddleware;pub use jobs::JobDispatcher;pub use jobs::JobExecutor;pub use jobs::JobQueue;pub use jobs::JobRecord;pub use jobs::JobRegistry;pub use jobs::Worker;pub use jobs::WorkerConfig;pub use mcp::McpToolEntry;pub use mcp::McpToolRegistry;pub use migrations::MigrationExecutor;pub use migrations::MigrationGenerator;pub use migrations::SchemaDiff;pub use observability::TelemetryConfig;pub use observability::TelemetryError;pub use observability::build_env_filter;pub use observability::init_telemetry;pub use observability::shutdown_telemetry;pub use rate_limit::RateLimiter;pub use realtime::AdaptiveTracker;pub use realtime::AdaptiveTrackingConfig;pub use realtime::AdaptiveTrackingStats;pub use realtime::ChangeListener;pub use realtime::InvalidationEngine;pub use realtime::RealtimeConfig;pub use realtime::RealtimeMessage;pub use realtime::SessionManager;pub use realtime::SessionServer;pub use realtime::SubscriptionManager;pub use webhook::WebhookEntry;pub use webhook::WebhookRegistry;pub use webhook::WebhookState;pub use webhook::webhook_handler;pub use workflow::EventStore;pub use workflow::WorkflowEntry;pub use workflow::WorkflowExecutor;pub use workflow::WorkflowRecord;pub use workflow::WorkflowRegistry;pub use workflow::WorkflowScheduler;pub use workflow::WorkflowSchedulerConfig;pub use workflow::WorkflowStepRecord;pub use sqlx;
Modules
- cluster
- cron
- daemon
- Daemon runtime components.
- db
- function
- gateway
- jobs
- mcp
- migrations
- Database migration system.
- observability
- rate_
limit - realtime
- signals
- Signals: built-in product analytics and frontend diagnostics.
- testing
- Testing utilities for FORGE applications.
- webhook
- Webhook runtime components.
- workflow
Macros
- assert_
err - Assert that a result is Err.
- assert_
err_ variant - Assert that an error matches a specific variant.
- assert_
job_ dispatched - Assert that a job was dispatched.
- assert_
ok - Assert that a result is Ok.
- assert_
workflow_ started - Assert that a workflow was started.