pub struct QueryCache { /* private fields */ }Expand description
A simple in-memory cache for query results.
Implementations
Sourceimpl QueryCache
impl QueryCache
Sourcepub fn with_max_entries(max_entries: usize) -> Self
pub fn with_max_entries(max_entries: usize) -> Self
Create a new query cache with a maximum number of entries.
Sourcepub fn get(
&self,
function_name: &str,
args: &Value,
auth_scope: Option<&str>,
) -> Option<Arc<Value>>
pub fn get( &self, function_name: &str, args: &Value, auth_scope: Option<&str>, ) -> Option<Arc<Value>>
Get a cached value if it exists and hasn’t expired.
Sourcepub fn set(
&self,
function_name: &str,
args: &Value,
auth_scope: Option<&str>,
value: Value,
ttl: Duration,
)
pub fn set( &self, function_name: &str, args: &Value, auth_scope: Option<&str>, value: Value, ttl: Duration, )
Set a cached value with a TTL.
Sourcepub fn set_arc(
&self,
function_name: &str,
args: &Value,
auth_scope: Option<&str>,
value: Arc<Value>,
ttl: Duration,
)
pub fn set_arc( &self, function_name: &str, args: &Value, auth_scope: Option<&str>, value: Arc<Value>, ttl: Duration, )
Store a pre-wrapped Arc<Value> in the cache.
Sourcepub fn invalidate(&self, function_name: &str, args: &Value)
pub fn invalidate(&self, function_name: &str, args: &Value)
Invalidate a specific cache entry.
Sourcepub fn invalidate_function(&self, function_name: &str)
pub fn invalidate_function(&self, function_name: &str)
Invalidate all entries for a function.
Sourcepub fn invalidate_by_tables(&self, query_names: &[&str])
pub fn invalidate_by_tables(&self, query_names: &[&str])
Invalidate all cached queries that depend on any of the given tables.