Module session

Module session 

Server-side session management for the signals pipeline.

Sessions are created when the first event arrives for a visitor_id. They are closed after session_timeout_mins of inactivity.

Functions

close_stale_sessions
Close stale sessions that have been inactive longer than the timeout.
identify_session
Link a user_id to an existing session (on identify).
spawn_session_reaper
Spawn a background task that periodically closes stale sessions.
upsert_session
Create or update a session for the given visitor.
upsert_user
Upsert user in forge_signals_users on identify().